==> fortunes-unix-2021.8.7.tar.gz: fortunes-unix-2021.8.7/README.md <==
# Installation
pip install [fortunes-unix](https://pypi.org/project/fortunes-unix/)

# Unix fortune data files

## DESCRIPTION
This package contains some [Unix](https://en.wikipedia.org/wiki/Unix) operating system aphorisms and quotes for the [fortune](https://en.wikipedia.org/wiki/Fortune_(Unix)) utility.

If you find other good ones, feel free to submit them in the repository's [discussion](https://github.com/HubTou/fortunes-unix/discussions) board or clone the repository and make a pull request.

## FILES
Filename|Sources
---|---
unix-philosophy|Mainly Wikipedia's [Unix Philosophy](https://en.wikipedia.org/wiki/Unix_philosophy), plus from some books
unix-quotes|Mainly extracted from fortune own [fortunes](https://github.com/HubTou/fortunes-freebsd-classic/blob/main/data/fortunes) database

## SEE ALSO
[fortune(6)](https://www.freebsd.org/cgi/man.cgi?query=fortune&manpath=FreeBSD+14.0-current),
[strfile(8)](https://www.freebsd.org/cgi/man.cgi?query=strfile)

## HISTORY
These data files are intended to be used with the [PNU project](https://github.com/HubTou/PNU)'s
re-implementation of the [fortune](https://github.com/HubTou/fortune) command.

## LICENSE
The original materials were fetched from miscellaneous Internet web sites.

## AUTHORS
[Hubert Tournier](https://github.com/HubTou) for the package.

Many people for the fortune files contents, though the following people stand out:
* [Eric S. Raymond](https://en.wikipedia.org/wiki/Eric_S._Raymond)
* [Mike Gancarz](https://www.linkedin.com/in/mike-gancarz-66a1204/)
* [Doug McIlroy](https://en.wikipedia.org/wiki/Douglas_McIlroy)
* [Peter H. Salus](https://en.wikipedia.org/wiki/Peter_H._Salus)
* [Brian Kernighan](https://en.wikipedia.org/wiki/Brian_Kernighan)
* [Rob Pike](https://en.wikipedia.org/wiki/Rob_Pike)
* and, of course, last but by no means least, [Dennis M. Ritchie](https://en.wikipedia.org/wiki/Dennis_Ritchie) and [Ken Thompson](https://en.wikipedia.org/wiki/Ken_Thompson), without whom none of this would have been possible !

==> fortunes-unix-2021.8.17.tar.gz: fortunes-unix-2021.8.17/README.md <==
# Installation
pip install [fortunes-unix](https://pypi.org/project/fortunes-unix/)

# Unix fortune data files

## DESCRIPTION
This package contains some [Unix](https://en.wikipedia.org/wiki/Unix) operating system aphorisms and quotes for the [fortune](https://en.wikipedia.org/wiki/Fortune_(Unix)) utility.

If you find other good ones, feel free to submit them in the repository's [discussion](https://github.com/HubTou/fortunes-unix/discussions) board or clone the repository and make a pull request.

## FILES
Filename|Sources
---|---
unix-philosophy|Mainly Wikipedia's [Unix Philosophy](https://en.wikipedia.org/wiki/Unix_philosophy), plus from some books
unix-quotes|Mainly extracted from fortune own [fortunes](https://github.com/HubTou/fortunes-freebsd-classic/blob/main/data/fortunes) database<br>And also from Brian Kernighan's "UNIX: A History and a Memoir"

## SEE ALSO
[fortune(6)](https://www.freebsd.org/cgi/man.cgi?query=fortune&manpath=FreeBSD+14.0-current),
[strfile(8)](https://www.freebsd.org/cgi/man.cgi?query=strfile)

## HISTORY
These data files are intended to be used with the [PNU project](https://github.com/HubTou/PNU)'s
re-implementation of the [fortune](https://github.com/HubTou/fortune) command.

## LICENSE
The original materials were fetched from miscellaneous Internet web sites.

## AUTHORS
[Hubert Tournier](https://github.com/HubTou) for the package.

Many people for the fortune files contents, though the following people stand out:
* [Eric S. Raymond](https://en.wikipedia.org/wiki/Eric_S._Raymond)
* [Mike Gancarz](https://www.linkedin.com/in/mike-gancarz-66a1204/)
* [Doug McIlroy](https://en.wikipedia.org/wiki/Douglas_McIlroy)
* [Peter H. Salus](https://en.wikipedia.org/wiki/Peter_H._Salus)
* [Brian Kernighan](https://en.wikipedia.org/wiki/Brian_Kernighan)
* [Rob Pike](https://en.wikipedia.org/wiki/Rob_Pike)
* and, of course, last but by no means least, [Dennis M. Ritchie](https://en.wikipedia.org/wiki/Dennis_Ritchie) and [Ken Thompson](https://en.wikipedia.org/wiki/Ken_Thompson), without whom none of this would have been possible !
